<h2 align="center">
  <br>
  <p align="center"><img src="https://raw.githubusercontent.com/reliablyhq/cli/main/public/logo.png"></p>
</h2>

<h4 align="center">Reliably CLI</h4>

<p align="center">
   <a href="https://github.com/reliablyhq/cli/releases">
   <img alt="Release" src="https://img.shields.io/github/v/release/reliablyhq/cli">
   <a href="https://goreportcard.com/report/github.com/reliablyhq/cli">
   <img alt="Go Report Card" src="https://goreportcard.com/badge/github.com/reliablyhq/cli">
   <a href="#">
   <img alt="Build" src="https://github.com/reliablyhq/cli/actions/workflows/build.yaml/badge.svg">
   <a href="https://github.com/reliablyhq/cli/issues">
   <img alt="GitHub issues" src="https://img.shields.io/github/issues/reliablyhq/cli?style=flat-square&logo=github&logoColor=white">
   <a href="https://github.com/reliablyhq/cli/blob/master/LICENSE.md">
   <img alt="License" src="https://img.shields.io/github/license/reliablyhq/cli">
</p>

<p align="center">
  <a href="#installation">Installation</a> •
  <a href="https://reliably.com/docs/">Documentation</a> •
  <a href="https://github.com/reliablyhq/cli/blob/main/CHANGELOG.md">ChangeLog</a> •
  <a href="#credits">Credits</a> •
</p>

---


# Usage

Please follow the [guidelines][] to walk you through Reliably's main features.

[guidelines]: https://reliably.dev/docs/guides/
